"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.cleanupTemp = exports.unpack = exports.downloadIntoTemp = exports.setUpTempDirectory = exports.checkEmptyDirectory = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const inquirer_1 = __importDefault(require("inquirer"));
const tmp_1 = __importDefault(require("tmp"));
const process_1 = __importDefault(require("process"));
const path_1 = __importDefault(require("path"));
const chalk = require("chalk");
const download_1 = require("./download");
exports.checkEmptyDirectory = (destination) => __awaiter(void 0, void 0, void 0, function* () {
    const directory = fs_extra_1.default.readdirSync(destination);
    if (directory.length) {
        console.log(`This directory already has files in it...`);
        const prompt = [
            {
                type: "confirm",
                name: "proceed",
                message: `Proceed? This may overwrite existing files`,
                default: true,
            },
        ];
        const answer = yield inquirer_1.default.prompt(prompt);
        if (!answer.proceed) {
            console.log("Initialization cancelled");
            process_1.default.exit();
        }
    }
});
exports.setUpTempDirectory = (logger) => {
    logger.log("Setting up a temporary directory...");
    const options = {
        unsafeCleanup: true,
    };
    try {
        const tmpDir = tmp_1.default.dirSync(options);
        return {
            tmpDir: tmpDir,
            path: path_1.default.join(tmpDir.name, "temp"),
            cleanup: tmpDir.removeCallback,
        };
    }
    catch (error) {
        throw error;
    }
};
exports.downloadIntoTemp = (template, path, logger) => __awaiter(void 0, void 0, void 0, function* () {
    logger.log("Downloading template from Github...");
    try {
        const download = yield download_1.githubDownload({
            url: `https://github.com/justinkaseman/create-web3-app/tree/master/packages/cwa-templates/${template}`,
            to: path,
        }, logger);
        if (download) {
            logger.succeed(`Downloading template from Github...${chalk.green("success!")}`, true);
            return;
        }
    }
    catch (error) {
        throw error;
    }
});
function promptOverwrites(fileCollisions, logger) {
    return __awaiter(this, void 0, void 0, function* () {
        const overwriteContents = [];
        if (logger)
            logger.stop();
        for (const file of fileCollisions) {
            const overwriting = [
                {
                    type: "confirm",
                    name: "overwrite",
                    message: `${file} already exists in this directory...\nOverwrite ${file}?`,
                    default: false,
                },
            ];
            const { overwrite } = yield inquirer_1.default.prompt(overwriting);
            if (overwrite) {
                fs_extra_1.default.removeSync(file);
                overwriteContents.push(file);
            }
        }
        if (logger)
            logger.start();
        return overwriteContents;
    });
}
function unpack(tempDir, destination, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { force, logger } = options;
        logger.log("Unpacking template...");
        fs_extra_1.default.ensureDirSync(destination);
        const contents = fs_extra_1.default.readdirSync(tempDir);
        const destinationContents = fs_extra_1.default.readdirSync(destination);
        const newContents = contents.filter((filename) => !destinationContents.includes(filename));
        const contentCollisions = contents.filter((filename) => destinationContents.includes(filename));
        let shouldCopy;
        if (force) {
            shouldCopy = contents;
        }
        else {
            const overwriteContents = yield promptOverwrites(contentCollisions, logger);
            shouldCopy = [...newContents, ...overwriteContents];
        }
        for (const file of shouldCopy) {
            fs_extra_1.default.copySync(`${tempDir}/${file}`, `${destination}/${file}`);
        }
        logger.succeed(`Unpacking template... ${chalk.green("success!")}`, true);
        return;
    });
}
exports.unpack = unpack;
function cleanupTemp(tempDirectory, logger) {
    return new Promise((resolve, reject) => {
        logger.log("Cleaning up...");
        tempDirectory === null || tempDirectory === void 0 ? void 0 : tempDirectory.cleanup();
        logger.succeed(`Cleaning up... ${chalk.green("success!")}`, true);
        resolve();
    });
}
exports.cleanupTemp = cleanupTemp;
//# sourceMappingURL=filesystem.js.map