"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("source-map-support/register");
const chalk = require("chalk");
const logger_1 = __importDefault(require("./logger"));
const filesystem_1 = require("./filesystem");
const args_1 = require("./args");
const install_1 = require("./install");
const initialize = (argv) => __awaiter(void 0, void 0, void 0, function* () {
    let tempDirectory;
    const destination = process.cwd();
    const logger = new logger_1.default(argv.verbose);
    try {
        tempDirectory = yield filesystem_1.setUpTempDirectory(logger);
        yield filesystem_1.downloadIntoTemp(argv.template, tempDirectory.path, logger);
        yield filesystem_1.unpack(tempDirectory.path + `/${argv.template}`, destination, {
            logger,
            force: argv.force,
        });
        yield filesystem_1.cleanupTemp(tempDirectory, logger);
        yield install_1.install(destination, logger);
        console.log(chalk.cyan("\nYour create-web3-app template is ready to go!\n\nCheck the README.md file for more information on getting started"));
    }
    catch (error) {
        tempDirectory === null || tempDirectory === void 0 ? void 0 : tempDirectory.cleanup();
        logger.fail(chalk.red("Failed to initialize template"));
        process.exit(1);
    }
});
function main(argv) {
    return __awaiter(this, void 0, void 0, function* () {
        yield args_1.promptMissingArgs(argv);
        if (!argv.force)
            yield filesystem_1.checkEmptyDirectory(process.cwd());
        initialize(argv);
    });
}
exports.default = main;
//# sourceMappingURL=initializer.js.map