"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.install = exports.hasPackageManager = void 0;
const spawn = require("child_process").spawn;
const chalk = require("chalk");
var PackageManagers;
(function (PackageManagers) {
    PackageManagers["yarn"] = "yarn";
    PackageManagers["npm"] = "npm";
})(PackageManagers || (PackageManagers = {}));
function hasPackageManager(name) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield spawn(`${name}`, ["--version"], { stdio: "ignore" });
            return true;
        }
        catch (e) {
            return false;
        }
    });
}
exports.hasPackageManager = hasPackageManager;
function install(destination, logger) {
    return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
        try {
            if (hasPackageManager(PackageManagers.yarn)) {
                logger.log("Installing packages with Yarn...");
                const result = spawn(`yarn install && cd client && yarn install`, {
                    cwd: destination,
                    shell: true,
                });
                result.stdout.on("data", (data) => {
                    logger.log(`Installing packages with Yarn... ${data}`);
                });
                result.on("close", (code) => {
                    if (code === 0) {
                        logger.succeed(`Installing packages with Yarn... ${chalk.green("success!")}`);
                        return resolve();
                    }
                    else {
                        reject("Could not install with Yarn");
                    }
                });
            }
            else if (hasPackageManager(PackageManagers.npm)) {
                logger.log("Installing packages with NPM...");
                const result = spawn(`npm install && cd client && npm install`, {
                    cwd: destination,
                    shell: true,
                });
                result.stdout.on("data", (data) => {
                    logger.log(`Installing packages with NPM... ${data}`);
                });
                result.on("close", (code) => {
                    if (code === 0) {
                        logger.succeed(`Installing packages with NPM... ${chalk.green("success!")}`);
                        return resolve();
                    }
                    else {
                        reject("Could not install with NPM");
                    }
                });
            }
        }
        catch (e) {
            console.log("Failed to install: ", e.message);
            reject(false);
        }
    }));
}
exports.install = install;
//# sourceMappingURL=install.js.map